# encoding: utf-8
from .__version__ import __version__

__author__ = "Yan Berezkin"
__maintainer__ = __author__
__package_name__ = "python_seller_active"
__email__ = "yan.berezkin@gmail.com"
__license__ = "MIT"
__version__ = __version__
__status__ = "Development"  # stable
__repo_url__ = "https://github.com/yberezkin/python_seller_active"
__bug_tracker__ = "https://github.com/yberezkin/python_seller_active/issues"
__credits__ = [""]
